from .utils import Hparam
from .utils import load, dump

"""
yamlparams

Python library for dot-access to parameters in yaml file
"""

__version__ = "1.0.5"
__author__ = 'Ilya Shamov'

if __name__ == "__main__":
    pass
