from setuptools import setup

setup(
    name='yamlparams',
    version='1.0.5',
    description='Python library for dot-access to parameters in yaml file',
    url='https://github.com/ARQtty/yamlparams',
    author='Ilya Shamov',
    author_email='ShamovIA@yandex.ru',
    license='MIT',
    packages=['yamlparams'],
    install_requires=['yamlenv'],

    classifiers=[],
)
